@@ -114,7 +114,7 @@ builtins.log = log  # type: ignore
 class log_progress(object):
     @staticmethod
     def progressBar(log_level, iterable):
-        if log_level > log.getEffectiveLevel():
+        if log_level < log.getEffectiveLevel():
             return iterable
 
         progress = progressbar.ProgressBar(
